@@ -130,6 +130,10 @@ impl super::Kubectl {
         }
     }
 
+    pub fn nodes(&self) -> api::Api<corev1::Node> {
+        self.api::<corev1::Node>()
+    }
+
     pub fn crds(&self) -> api::Api<apiextensionsv1::CustomResourceDefinition> {
         self.api::<apiextensionsv1::CustomResourceDefinition>()
     }
